==> Polarity-2022.2.15.tar.gz: Polarity-2022.2.15/README.md <==
# Polarity
> 🍝 Spaghetti powered, cross-platform mass downloader and metadata extractor for video streaming platforms.

## Features
- **Cross-platform** (Linux, Windows, MacOS, Android, anything that can run Python and FFmpeg)
- **Multilanguage**
### Download features
- **Resolution selection**
- **Subtitles support**
- **Custom name formatting**
- **Multi-threaded downloads**
- **External downloader support**
### Other features
- **Search in supported extractors**
- **_(Minimal)_ Live TV support**


## Installation
- ### [Windows Installation <img src="https://aveeryy.github.io/icons/small/Windows.png" alt="Windows" width="16"/>](https://github.com/aveeryy/Polarity/wiki/Installing#windows-)
- ### [Linux Installation <img src="https://aveeryy.github.io/icons/small/Linux.png" alt="Linux" width="16"/>](https://github.com/aveeryy/Polarity/wiki/Installing#linux-)
- ### [Android Installation <img src="https://aveeryy.github.io/icons/small/Android.png" alt="Android" width="16"/>](https://github.com/aveeryy/Polarity/wiki/Installing#android-)

## Supported websites
| | Premium | Subtitles | Search
|:-:|:-:|:-:|:-:|
| Atresplayer | ✔️ | ✔️ | ✔️ 
| Crunchyroll  | ✔️ | ✔️ | ✔️️

> Note: "🍝" means in progress

## Configuration
Configuration files are found at:

<img src="https://aveeryy.github.io/icons/small/Windows.png" alt="Windows" width="16"/> Windows `C:\Users\<username>\AppData\Local\Polarity\`

<img src="https://aveeryy.github.io/icons/small/Linux.png" alt="Linux" width="16"/> Linux `/home/<username>/.local/share/Polarity/`

<img src="https://aveeryy.github.io/icons/small/MacOS.png" alt="MacOS" width="16"/> macOS `/Users/<username>/Library/Application Support/.olarity/`

<img src="https://aveeryy.github.io/icons/small/Android.png" alt="Android" width="16"/> Android `/storage/emulated/0/.Polarity/`
    

## Testing devices
<img src="https://aveeryy.github.io/icons/small/Linux.png" alt="Linux" width="16"/>  **Arch Linux** (latest kernel)

<img src="https://aveeryy.github.io/icons/small/Windows.png" alt="Windows" width="16"/>  **Windows 10** (Ameliorated)

<img src="https://aveeryy.github.io/icons/small/Android.png" alt="Android" width="16"/>  **Android 11** (Termux latest/4.9.118)

<img src="https://aveeryy.github.io/icons/small/Android.png" alt="Android" width="16"/>  **Android 10** (Termux 0.101/4.4.210-Sultan)

## Legal disclaimer
This application is not affiliated nor endorsed by any of the sites mentioned above. This application enables downloading videos for *offline viewing* which may be forbidden in your country or cause a violation of the Terms of Service of your Internet Service Provider and/or streaming provider. Neither I nor this tool are responsible of your actions and therefore, consequences.

### About Cloudflare and Polarity
Polarity uses [cloudscraper](https://github.com/VeNoMouS/cloudscraper) to bypass Cloudflare protections, by making too many requests your IP address could be blocked by Cloudflare for 24 hours or more. This can be circunvented by restarting your router if you have a dynamic address, using a proxy / VPN or using a captcha recognition service. If you can't use any of the before mentioned circunventions you will have to wait to use Polarity with that streaming service again.

==> Polarity-2022.4.16.post1.tar.gz: Polarity-2022.4.16.post1/README.md <==
# Polarity
> 🍝 Spaghetti powered, cross-platform mass downloader and metadata extractor for video streaming platforms.

## Features
- **Cross-platform** (Linux, Windows, MacOS, Android, anything that can run Python and FFmpeg)
- **Multilanguage**
### Download features
- **Resolution selection**
- **Subtitles support**
- **Custom name formatting**
- **Multi-threaded downloads**
- **External downloader support**
### Other features
- **Search in supported extractors**
- **_(Minimal)_ Live TV support**


## Installation
- ### [Windows Installation <img src="https://aveeryy.github.io/icons/small/Windows.png" alt="Windows" width="16"/>](https://github.com/aveeryy/Polarity/wiki/Installing#windows-)
- ### [Linux Installation <img src="https://aveeryy.github.io/icons/small/Linux.png" alt="Linux" width="16"/>](https://github.com/aveeryy/Polarity/wiki/Installing#linux-)
- ### [Android Installation <img src="https://aveeryy.github.io/icons/small/Android.png" alt="Android" width="16"/>](https://github.com/aveeryy/Polarity/wiki/Installing#android-)

## Supported websites
| | Premium | Subtitles | Search
|:-:|:-:|:-:|:-:|
| Atresplayer | ✔️ | ✔️ | ✔️ 
| Crunchyroll  | ✔️ | ✔️ | ✔️️
| Pokémon TV  | - | ✔️ | -

> "🍝": in progress

> "-": not applicable

## Configuration
Configuration files are found at:

<img src="https://aveeryy.github.io/icons/small/Windows.png" alt="Windows" width="16"/> Windows `C:\Users\<username>\AppData\Local\Polarity\`

<img src="https://aveeryy.github.io/icons/small/Linux.png" alt="Linux" width="16"/> Linux `/home/<username>/.local/share/Polarity/`

<img src="https://aveeryy.github.io/icons/small/MacOS.png" alt="MacOS" width="16"/> macOS `/Users/<username>/Library/Application Support/.olarity/`

<img src="https://aveeryy.github.io/icons/small/Android.png" alt="Android" width="16"/> Android `/storage/emulated/0/.Polarity/`
    

## Testing devices
<img src="https://aveeryy.github.io/icons/small/Linux.png" alt="Linux" width="16"/>  **Arch Linux** (Latest kernel/Python)

<img src="https://aveeryy.github.io/icons/small/Windows.png" alt="Windows" width="16"/>  **Windows 10** (Ameliorated/Python 3.9)

<img src="https://aveeryy.github.io/icons/small/Android.png" alt="Android" width="16"/>  **Android 12** (Termux/Python 3.10)

## Legal disclaimer
This application is not affiliated nor endorsed by any of the sites mentioned above. This application enables downloading videos for *offline viewing* which may be forbidden in your country or cause a violation of the Terms of Service of your Internet Service Provider and/or streaming provider. Neither I nor this tool are responsible of your actions and therefore, consequences.
